@@ -3,7 +3,7 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.111012';
+our $VERSION = '0.120927';
 
 use Acme::CPANAuthors::Register (
     AERDAN    => 'Kiyoshi Aman',
@@ -11,14 +11,17 @@ use Acme::CPANAuthors::Register (
     AHIROSE   => 'Akira HIROSE',
     AKIHITO   => 'Akihito Takeda',
     AKIRA     => 'Akira Hangai',
+    AKIYM     => 'Takumi Akiyama',
     AKOBA     => 'Atsushi Kobayashi',
     AMARISAN  => 'Ryoji Tanida',
+    ANAZAWA   => 'Ryo Anazawa',
     AQL       => 'Tetsuya Toyoda',
     ARISAWA   => 'Kosuke Arisawa',
     ARUTEIDO  => 'satoshi ishikawa',
     ASAKURA   => 'ASAKURA Takuji',
     ASARIH    => 'Hiro Asari',
     ASKADNA   => 'Shinichiro Aska',
+    AYANOKOUZ => 'AYANOKOUZI, Ryuunosuke',
     BANB      => 'ITO Nobuaki',
     BASHI     => 'Toshimasa Ishibashi',
     BAYASHI   => 'Dai Okabayashi',
@@ -30,6 +33,7 @@ use Acme::CPANAuthors::Register (
     CHIBA     => 'Masahiro Chiba',
     CLAIRVY   => 'NAGAYA Shinichiro',
     COHTAN    => 'Kota Sakoda',
+    CSIDE     => 'Hiroki Honda',
     DAIBA     => 'DAIBA, Keiichi',
     DAMEO     => 'Takashi Higashigata',
     DANJOU    => 'Nobuo Danjou',
@@ -39,6 +43,7 @@ use Acme::CPANAuthors::Register (
     DRAWNBOY  => 'Hideaki Tanaka',
     FUJIMURA  => 'FUJIMURA Yuki',
     FUJIWARA  => 'Fujiwara Shunichiro',
+    FUKATA    => 'Tatsuya Fukata',
     FUKUDA    => 'Keisuke Fukuda',
     FUTAYA    => 'Satoshi Futaya',
     GAOU      => 'Kazuharu Arakawa',
@@ -47,12 +52,14 @@ use Acme::CPANAuthors::Register (
     HAMANO    => 'Tsukasa Hamano',
     HAOYAYOI  => 'Soshi Tamura',
     HATA      => 'Masanori HATA',
+    HATTORI   => 'Fumiaki Hattori',
     HAYASHI   => 'Hiroo HAYASHI',
     HEDWIG    => 'Yusuke Sugiyama',
     HHORIUCHI => 'Hiroki Horiuchi',
     HIDE      => 'Hideo Kimura',
     HIGU      => 'Higuchi hiroyuki',
     HIKARINE  => 'Hajime Kurita',
+    HIMACHOCO => 'Wataru Seto',
     HIMAZU    => 'Hideyo Imazu',
     HIO       => 'YAMASHINA Hio',
     HIRAFOO   => 'Tomoya Hirano',
@@ -66,10 +73,11 @@ use Acme::CPANAuthors::Register (
     HKOBA     => 'KOBAYASI, Hiroaki',
     HOLLY     => 'Akira Horimoto',
     HORIUCHI  => 'Yasuhiro Horiuchi',
+    HRK       => 'Haruka Kataoka',
+    HWAT      => 'WATANABE Hiroaki',
     ICHI      => 'Takuya Ichikawa',
     IHARA     => 'Ikuhiro IHARA',
     IKEBE     => 'IKEBE Tomohiro',
-    IKEGAMI   => 'ikegami',
     IKUTA     => 'Masahito Ikuta',
     IIZUKA    => 'Nao Iizuka',
     INA       => 'INABA Hitoshi',
@@ -88,19 +96,23 @@ use Acme::CPANAuthors::Register (
     KAWASAKI  => 'Kawasaki Yusuke',
     KAZEBURO  => 'Masahiro Nagano',
     KAZUHO    => 'Kazuho Oku',
+    KAZUNORI  => 'Kazunori Minoda',
     KEISUKE   => 'Keisuke Kuramata',
     KENJIRO   => 'Kenjiro Hirakawa',
     KENTARO   => 'Kentaro Kuribayashi',
     KIMOTO    => 'Yuki Kimoto',
     KIMURA    => 'Takeshi Kimura',
     KINSAN    => 'Hitoshi Yokozawa',
+    KISEKI    => 'keita iseki',
     KITAMAKI  => 'ryo kitamaki',
+    KIWANAMI  => 'Masashi Sakurai',
     KMIYAZAKI => 'Keitaro Miyazaki',
     KNAGANO   => 'Keiichiro Nagano',
     KNOK      => 'NOKUBI Takatsugu',
     KOBAYASHI => 'Takeshi Kobayashi',
     KOBAYASI  => 'Hiroyuki Kobayasi',
     KOGA      => 'Seiki Koga',
+    KOJIMAGI  => 'Koji Takiguchi',
     KOJUN     => 'Kojun Ueno',
     KOKOGIKO  => 'OHTSUKA Ko-hei',
     KONDO     => 'Yoshiyuki KONDO',
@@ -122,12 +134,15 @@ use Acme::CPANAuthors::Register (
     KZFM      => 'Kazufumi Ohkawa',
     KZTOMITA  => 'Kazuyoshi Tomita',
     KZYS      => 'Kato Kazuyoshi',
+    LAPIS     => 'Junichi Iwasaki',
     LUSHE     => 'Masatoshi Mizuno',
     LYOKATO   => 'Lyo Kato',
+    MAHIRO    => 'Mahiro Ando',
     MAHITO    => 'Hogelist',
     MAIDO     => 'Masahiro Funakoshi',
     MAKAMAKA  => 'Makamaka Hannyaharamitu',
     MAKOTO    => 'Shin Honda',
+    MAND      => 'Yuki Manno',
     MAOE      => 'Mitsutoshi Aoe',
     MASAHITO  => 'Masahito Yoshida',
     MASAKI    => 'NAKAGAWA Masaki',
@@ -147,6 +162,7 @@ use Acme::CPANAuthors::Register (
     MIZZY     => 'Gosuke Miyashita',
     MORIYA    => 'Moriya Masaki',
     MURATA    => 'Shingo Murata',
+    MURATAYA  => 'MURATA Yasuhisa',
     MYUJI     => 'Yuji Maeda',
     NABESHIMA => 'Masaaki NABESHIMA',
     NAITO     => 'Naoyuki Ito',
@@ -155,6 +171,7 @@ use Acme::CPANAuthors::Register (
     NAOYA     => 'Naoya Ito',
     NAOYAT    => 'Naoya "naochan" Tozuka',
     NAOYUKI   => 'Naoyuki Ito',
+    NARAZAKA  => 'N Narazaka',
     NARUSE    => 'NARUSE, Yui',
     NEJIGANE  => 'Yu Nejigane',
     NEKOKAK   => 'Atsushi Kobayashi',
@@ -163,6 +180,7 @@ use Acme::CPANAuthors::Register (
     NGS       => 'Atsushi NAGASE',
     NISHIGAYA => 'NISHIGAYA, Yuki',
     NISHIKAWA => 'Kazuhiro Nishikawa',
+    NOGUCHI   => 'Tatsuya Noguchi',
     NOZZZZZ   => 'Tetsunari Nozaki',
     NTSUTSUMI => 'Naoya Tsutsumi',
     NYARLA    => 'Naoki Okamura',
@@ -171,10 +189,13 @@ use Acme::CPANAuthors::Register (
     OISHI     => 'Eisuke Oishi',
     ONISHI    => 'Yasuhiro Onishi',
     OUEST     => 'Daisuke NISHISAKA',
+    OVERLAST  => 'Toshinori Sato',
     OYAMA     => 'Hiroyuki OYAMA',
     OZAWA     => 'OZAWA Sakuro',
     PAINA     => 'SATO Taisuke',
+    PAWAPAWA  => 'Kohei Yoshioka',
     PEN       => 'Abe Masahiro',
+    PERFORB   => 'Yusuke Maeda',
     PIA       => 'Michiya Honda',
     PIROLIX   => 'Hiroyuki UENISHI',
     POCKET    => 'Masato Sogame',
@@ -202,15 +223,20 @@ use Acme::CPANAuthors::Register (
     SHIMI     => 'Kazuhito Shimizu',
     SHINPEI   => 'HAYASHI, Shinpei',
     SHIRAIWA  => 'Kazuma Shiraiwa',
+    SHOHEIK   => 'Shohei Kameda',
     SHOT      => 'Shota Takayama',
+    SKJM      => 'Shin Kojima',
     SKONNO    => 'Satoshi Konno',
     SKUBOTA   => 'Satoshi KUBOTA',
     SNGJOKEN  => 'Shingo Kikugawa',
+    SNUMANO   => 'Shugo Numano',
     SONGMU    => 'Masayuki Matsuki',
     SSEI      => 'Shinichiro Sei',
+    STAKASHIO => 'Shin Takashio',
     SUGMAK    => 'Makoto Sugiyama',
     SUZUKI    => 'Yuji Suzuki',
     SYNCLOVER => 'Naoya Sato',
+    SYOHEX    => 'Syohei Yoshida',
     SZARATE   => 'Santiago Zarate',
     TAGOMORIS => 'Satoshi Tagomori',
     TAIY      => 'Taisuke Yamada',
@@ -245,6 +271,7 @@ use Acme::CPANAuthors::Register (
     TOPIA     => 'Tatuya Noda',
     TORU      => 'Toru Hisai',
     TOSHIFJW  => 'Toshimitsu FUJIWARA',
+    TOSHIOITO => 'Toshio Ito',
     TRAVAIL   => 'Tomoyuki SAWA',
     TSUCCHI   => 'Takuya Tsuchida',
     TSUKAMOTO => 'Makio Tsukamoto',
@@ -252,6 +279,7 @@ use Acme::CPANAuthors::Register (
     TURUGINA  => 'KATOU Akira',
     TYANO     => 'Tatsuhiro YANO',
     TYPESTER  => 'Daisuke Murase',
+    UASI      => 'Tomoki Aonuma',
     UMEMOTO   => 'Hajimu Umemoto',
     UNLEARNED => 'Takashi Uesugi',
     USUALOMA  => 'Taku Amano',
